==> jc-1.4.0.tar.gz: soot/jimple/spark/fieldrw/FieldTagAggregator.h <==
// public class soot.jimple.spark.fieldrw.FieldTagAggregator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class a9a9e7e01a276fdf soot_jimple_spark_fieldrw_FieldTagAggregator
// @dep_class 62bfb9a4e3139951 soot_tagkit_TagAggregator

// header file dependencies
// @dep_header soot_tagkit_TagAggregator

#include "soot/tagkit/TagAggregator.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldTagAggregator_H_
#define _JC_soot_jimple_spark_fieldrw_FieldTagAggregator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$aggregatedName$7a98c3a9832c3f1d(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *);
extern void _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$considerTag$d40cb36f11e25c13(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$wantTag$6a073a64332a7aa0(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$aggregatedName$7a98c3a9832c3f1d;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$considerTag$d40cb36f11e25c13;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$wantTag$6a073a64332a7aa0;

// Static methods
extern struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$v$8b86c31282e05c5b(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods {
	struct _jc_java_lang_String$object	*(*aggregatedName$7a98c3a9832c3f1d)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *);
	void	(*considerTag$d40cb36f11e25c13)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *, struct _jc_object *);
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	jboolean	(*wantTag$6a073a64332a7aa0)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_tagkit_TagAggregator$vmethods	soot_tagkit_TagAggregator;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods	soot_jimple_spark_fieldrw_FieldTagAggregator;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs {
    _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs	soot_jimple_spark_fieldrw_FieldTagAggregator;
    _jc_soot_tagkit_TagAggregator$sub_refs	soot_tagkit_TagAggregator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_tagkit_TagAggregator$sub_nonrefs	soot_tagkit_TagAggregator;
    _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs	soot_jimple_spark_fieldrw_FieldTagAggregator;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object {
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldTagAggregator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldTagAggregator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/fieldrw/FieldTagAggregator.h <==
// public class soot.jimple.spark.fieldrw.FieldTagAggregator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class a9a9e7e01a276fdf soot_jimple_spark_fieldrw_FieldTagAggregator
// @dep_class 62bfb9a4e3139951 soot_tagkit_TagAggregator

// header file dependencies
// @dep_header soot_tagkit_TagAggregator

#include "soot/tagkit/TagAggregator.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldTagAggregator_H_
#define _JC_soot_jimple_spark_fieldrw_FieldTagAggregator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$aggregatedName$7a98c3a9832c3f1d(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$considerTag$d40cb36f11e25c13(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$wantTag$6a073a64332a7aa0(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$aggregatedName$7a98c3a9832c3f1d;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$considerTag$d40cb36f11e25c13;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method_info$wantTag$6a073a64332a7aa0;

// Static methods
extern struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$method$v$8b86c31282e05c5b(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods {
	struct _jc_java_lang_String$object	*(*aggregatedName$7a98c3a9832c3f1d)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *) _JC_JCNI_ATTR;
	void	(*considerTag$d40cb36f11e25c13)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*wantTag$6a073a64332a7aa0)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_tagkit_TagAggregator$vmethods	soot_tagkit_TagAggregator;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vmethods	soot_jimple_spark_fieldrw_FieldTagAggregator;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs {
    _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_refs	soot_jimple_spark_fieldrw_FieldTagAggregator;
    _jc_soot_tagkit_TagAggregator$sub_refs	soot_tagkit_TagAggregator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_tagkit_TagAggregator$sub_nonrefs	soot_tagkit_TagAggregator;
    _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$sub_nonrefs	soot_jimple_spark_fieldrw_FieldTagAggregator;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$object {
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldTagAggregator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$vtype _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldTagAggregator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldTagAggregator$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldTagAggregator_H_ */
